#!/bin/sh

test_description="Test properties of added files"

. ./sharness.sh

test_expect_success 'Setup local repo and working copy' '
svnadmin create foo &&
cat $SHARNESS_BUILD_DIRECTORY/pre-commit | sed -e "s:/repo:$HOME/foo:" > foo/hooks/pre-commit &&
chmod +x foo/hooks/pre-commit &&
cp $SHARNESS_BUILD_DIRECTORY/check-mime-type.pl foo/hooks/check-mime-type.pl &&
chmod +x foo/hooks/check-mime-type.pl &&
svn co "file://$HOME/foo" bar
'

test_expect_success 'Add file with text/eol properties' '
cd bar &&
echo "this is text/eol" > text-eol &&
svn add text-eol &&
svn propset svn:mime-type text/plain text-eol &&
svn propset svn:eol-style native text-eol &&
svn ci -m "initial state text-eol" text-eol &&
cd ..
'

test_expect_success 'Add file with non-text property' '
cd bar &&
echo "this is non-text" > non-text &&
svn add non-text &&
svn propset svn:mime-type application/octet-stream non-text &&
svn ci -m "initial state non-text" non-text &&
cd ..
'

test_expect_success 'Add file with text property without eol' '
cd bar &&
echo "this is text-no-eol" > text-no-eol &&
svn add text-no-eol &&
svn propset svn:mime-type text/plain text-no-eol &&
test_must_fail svn ci -m "initial state text-no-eol" text-no-eol &&
cd ..
'

test_expect_success 'Add file without properties' '
cd bar &&
echo "this is no-properties" > no-properties &&
svn add no-properties &&
test_must_fail svn ci -m "initial state no-properties" no-properties &&
cd ..
'
export SPOOF=`cat <<EOF
line 1:
  svn:mime-type
    text/plain
  svn:eol-style
    native
EOF
`
export SPOOF2=`cat <<EOF
line 1:
svn:mime-type
  text/plain
svn:eol-style
  native
EOF
`
test_expect_success 'Add file trying to spoof text/eol check' '
cd bar &&
echo "this is spoof" > spoof &&
svn add spoof &&
svn propset spoof "$SPOOF" spoof &&
svn propset spoof2 "$SPOOF2" spoof &&
test_must_fail svn ci -m "initial state spoof" spoof &&
cd ..
'

test_done

# vi: set ft=sh :
