#!/bin/sh

test_description="Test properties of updated files"

. ./sharness.sh

test_expect_success 'Setup local repo and working copy' '
svnadmin create foo &&
cat $SHARNESS_BUILD_DIRECTORY/pre-commit | sed -e "s:/repo:$HOME/foo:" > foo/hooks/pre-commit &&
chmod +x foo/hooks/pre-commit &&
cp $SHARNESS_BUILD_DIRECTORY/check-mime-type.pl foo/hooks/check-mime-type.pl &&
chmod +x foo/hooks/check-mime-type.pl &&
svn co "file://$HOME/foo" bar
'

test_expect_success 'Update file with text/eol add lock' '
cd bar &&
echo "this is text/eol new-prop" > text-eol-np &&
svn add text-eol-np &&
svn propset svn:mime-type text/plain text-eol-np &&
svn propset svn:eol-style native text-eol-np &&
svn ci -m "initial state text-eol-np" text-eol-np &&
svn propset svn:needs-lock "*" text-eol-np &&
svn ci -m "added svn:needs-lock property" text-eol-np &&
cd ..
'

test_expect_success 'Update file with text/eol/lock remove lock' '
cd bar &&
echo "this is text/eol new-prop-del" > text-eol-dp &&
svn add text-eol-dp &&
svn propset svn:mime-type text/plain text-eol-dp &&
svn propset svn:eol-style native text-eol-dp &&
svn propset svn:needs-lock "*" text-eol-dp &&
svn ci -m "initial state text-eol-dp" text-eol-dp &&
svn propdel svn:needs-lock text-eol-dp &&
svn ci -m "removed svn:needs-lock property" text-eol-dp &&
cd ..
'

test_expect_success 'Update file with text/eol remove text' '
cd bar &&
echo "this is text/eol new-prop-del-2" > text-eol-dp2 &&
svn add text-eol-dp2 &&
svn propset svn:mime-type text/plain text-eol-dp2 &&
svn propset svn:eol-style native text-eol-dp2 &&
svn ci -m "initial state text-eol-dp2" text-eol-dp2 &&
svn propdel svn:mime-type text-eol-dp2 &&
test_must_fail svn ci -m "removed svn:mime-type property" text-eol-dp2 &&
cd ..
'

test_expect_success 'Update file with text/eol remove eol' '
cd bar &&
echo "this is text/eol new-prop-del-3" > text-eol-dp3 &&
svn add text-eol-dp3 &&
svn propset svn:mime-type text/plain text-eol-dp3 &&
svn propset svn:eol-style native text-eol-dp3 &&
svn ci -m "initial state text-eol-dp3" text-eol-dp3 &&
svn propdel svn:eol-style text-eol-dp3 &&
test_must_fail svn ci -m "removed svn:eol-style property" text-eol-dp3 &&
cd ..
'

test_expect_success 'Update file with text/eol, add non-text remove eol' '
cd bar &&
echo "this is text/eol new-prop-del-4" > text-eol-dp4 &&
svn add text-eol-dp4 &&
svn propset svn:mime-type text/plain text-eol-dp4 &&
svn propset svn:eol-style native text-eol-dp4 &&
svn ci -m "initial state text-eol-dp4" text-eol-dp4 &&
svn propdel svn:eol-style text-eol-dp4 &&
svn propset svn:mime-type application/octet-stream text-eol-dp4 &&
svn ci -m "made this a non-text file" text-eol-dp4 &&
cd ..
'

test_expect_success 'Update file with non-text, add text/eol' '
cd bar &&
echo "this is text/eol new-prop-del-5" > text-eol-dp5 &&
svn add text-eol-dp5 &&
svn propset svn:mime-type application/octet-stream text-eol-dp5 &&
svn ci -m "initial state text-eol-dp5" text-eol-dp5 &&
svn propset svn:mime-type text/plain text-eol-dp5 &&
svn propset svn:eol-style native text-eol-dp5 &&
svn ci -m "made this a text file" text-eol-dp5 &&
cd ..
'

test_done

# vi: set ft=sh :
